        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260821 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260821 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>26</strong> miembros: 37 <strong>control</strong><br>0,1,2,3,4,5,6,7,8,9,13,14,15,16,17,21,22,24,25,26,27,29,30,32,33,35,36,38,41,42,43,44,45,47,48,49,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260821 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 14 <br>10,11,12,18,19,20,23,28,31,34,37,39,40,46';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260821 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260821 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>26</strong> miembros: 37 <strong>control</strong><br>0,1,2,3,4,5,6,7,8,9,13,14,15,16,17,21,22,24,25,26,27,29,30,32,33,35,36,38,41,42,43,44,45,47,48,49,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260821 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 14 <br>10,11,12,18,19,20,23,28,31,34,37,39,40,46';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260821 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260821 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>26</strong> miembros: 37 <strong>control</strong><br>0,1,2,3,4,5,6,7,8,9,13,14,15,16,17,21,22,24,25,26,27,29,30,32,33,35,36,38,41,42,43,44,45,47,48,49,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260821 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 14 <br>10,11,12,18,19,20,23,28,31,34,37,39,40,46';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260821 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260821 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>26</strong> miembros: 37 <strong>control</strong><br>0,1,2,3,4,5,6,7,8,9,13,14,15,16,17,21,22,24,25,26,27,29,30,32,33,35,36,38,41,42,43,44,45,47,48,49,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260821 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 14 <br>10,11,12,18,19,20,23,28,31,34,37,39,40,46';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260821 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260821 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>26</strong> miembros: 37 <strong>control</strong><br>0,1,2,3,4,5,6,7,8,9,13,14,15,16,17,21,22,24,25,26,27,29,30,32,33,35,36,38,41,42,43,44,45,47,48,49,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260821 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>39</strong> miembros: 14 <br>10,11,12,18,19,20,23,28,31,34,37,39,40,46';}
}
